@@ -44,6 +44,9 @@ int main(int argc, char *argv[])
 	musicOn =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource(openSound.c_str()));
 	musicOff =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource(closeSound.c_str()));
 	
+//	musicOn =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/lockdaemon/open.mp3"));
+//	musicOff =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource(closeSound.c_str()));
+	
 	QWidget::connect(musicOn,SIGNAL(finished()),musicOn,SLOT(stop()));
 	QWidget::connect(musicOff,SIGNAL(finished()),musicOff,SLOT(stop()));
 	
@@ -320,7 +323,8 @@ static DBusHandlerResult signal_filter (DBusConnection *connection, DBusMessage
 void readConfig()
 {
 	std::string line;
-	std::ifstream myfile ("/home/user/MyDocs/.images/lockdaemon.conf");
+	//std::ifstream myfile ("/home/user/MyDocs/.images/lockdaemon.conf");
+	std::ifstream myfile ("/home/opt/lockdaemon/lockdaemon.conf");
 	if (myfile.is_open())
       	{
 		int i=0;
